@@ -901,7 +901,7 @@ pub fn distribute_all(einsum: &Einsum) -> Option<Add> {
     let mut distributed = distribute(einsum, add_op_idxs[0], true).unwrap();
     if add_op_idxs.len() > 1 {
         distributed = distributed
-            .map_children(&mut |node: &Circuit| match &*node {
+            .map_children(&mut |node: CircuitRc| match &**node {
                 Circuit::Einsum(inner) => {
                     Ok::<CircuitRc, CircuitConstructionError>(distribute_all(inner).unwrap().rc())
                 }
@@ -1039,10 +1039,10 @@ pub fn einsum_concat_to_add(einsum: &Einsum) -> Option<Add> {
                     return Some((concat_idx, concat));
                 }
             }
-            return None;
+            None
         })
         .collect();
-    if potential_concats_and_idx.len() == 0 {
+    if potential_concats_and_idx.is_empty() {
         return None;
     }
 
@@ -1057,10 +1057,10 @@ pub fn einsum_concat_to_add(einsum: &Einsum) -> Option<Add> {
             // Replace the concatted `a` dimension with the partial `a` we're mapping over, then
             // leave everything else in the output alone.
             new_args[concat_idx] = (node.clone(), einsum.args[concat_idx].1.clone());
-            return Einsum::nrc(new_args, einsum.out_axes.clone(), None);
+            Einsum::nrc(new_args, einsum.out_axes.clone(), None)
         })
         .collect();
-    return Some(Add::try_new(inner_einsum, None).unwrap());
+    Some(Add::try_new(inner_einsum, None).unwrap())
 }
 
 #[pyfunction]
