@@ -92,10 +92,7 @@ impl CircuitNode for Einsum {
         Box::new(self.args.iter().map(|a| a.0.clone()))
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        mut f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
@@ -602,10 +599,7 @@ impl CircuitNode for Add {
         Box::new(self.nodes.iter().cloned())
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        mut f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
@@ -792,10 +786,7 @@ impl CircuitNode for Rearrange {
         Box::new(std::iter::once(self.node.clone()))
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        mut f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
@@ -984,10 +975,7 @@ impl CircuitNode for Index {
         Box::new(std::iter::once(self.node.clone()))
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        mut f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
@@ -1158,10 +1146,7 @@ impl CircuitNode for Concat {
         Box::new(self.nodes.iter().cloned())
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        mut f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
@@ -1353,10 +1338,7 @@ impl CircuitNode for Scatter {
             .collect()]
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        mut f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
