@@ -246,10 +246,7 @@ impl CircuitNode for GeneralFunction {
         Box::new(self.nodes.iter().cloned())
     }
 
-    fn map_children_enumerate<'a, F, E>(
-        &'a self,
-        mut f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
