@@ -117,7 +117,7 @@ pub trait CircuitNode: CircuitNodePrivate {
 
     fn children<'a>(&'a self) -> Box<dyn Iterator<Item = CircuitRc> + 'a>;
 
-    fn map_children_enumerate<'a, F, E>(&'a self, f: F) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, f: F) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
         CircuitConstructionError: From<E>,
@@ -177,7 +177,7 @@ pub trait CircuitNode: CircuitNodePrivate {
         result
     }
 
-    fn map_children<'a, F, E>(&'a self, mut f: F) -> Result<Self, CircuitConstructionError>
+    fn map_children<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
         CircuitConstructionError: From<E>,
@@ -186,7 +186,7 @@ pub trait CircuitNode: CircuitNodePrivate {
         self.map_children_enumerate(|_i, x| f(x))
     }
 
-    fn map_children_idxs<'a, F, E>(&'a self, mut f: F) -> Result<Self, CircuitConstructionError>
+    fn map_children_idxs<F, E>(&self, mut f: F) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
         CircuitConstructionError: From<E>,
@@ -195,7 +195,7 @@ pub trait CircuitNode: CircuitNodePrivate {
         self.map_children_enumerate(|i, _x| f(i))
     }
 
-    fn map_children_unwrap<'a, F>(&'a self, mut f: F) -> Self
+    fn map_children_unwrap<F>(&self, mut f: F) -> Self
     where
         Self: Sized,
         F: FnMut(CircuitRc) -> CircuitRc,
@@ -204,7 +204,7 @@ pub trait CircuitNode: CircuitNodePrivate {
             .unwrap()
     }
 
-    fn map_children_unwrap_enumerate<'a, F>(&'a self, mut f: F) -> Self
+    fn map_children_unwrap_enumerate<F>(&self, mut f: F) -> Self
     where
         Self: Sized,
         F: FnMut(usize, CircuitRc) -> CircuitRc,
@@ -213,7 +213,7 @@ pub trait CircuitNode: CircuitNodePrivate {
             .unwrap()
     }
 
-    fn map_children_unwrap_idxs<'a, F>(&'a self, mut f: F) -> Self
+    fn map_children_unwrap_idxs<F>(&self, mut f: F) -> Self
     where
         Self: Sized,
         F: FnMut(usize) -> CircuitRc,
@@ -223,7 +223,7 @@ pub trait CircuitNode: CircuitNodePrivate {
     }
 
     /// if any return Some, return child mapped, otherwise None
-    fn map_children_op<'a, F>(&'a self, mut f: F) -> Option<Self>
+    fn map_children_op<F>(&self, mut f: F) -> Option<Self>
     where
         Self: Sized,
         F: FnMut(CircuitRc) -> Option<CircuitRc>,
@@ -327,10 +327,7 @@ pub trait CircuitNodeAutoName: CircuitNode {
 pub trait CircuitNodeUnion {
     fn as_trait_obj(&self) -> &dyn CircuitNode;
     fn as_trait_obj_mut(&mut self) -> &mut dyn CircuitNode;
-    fn map_children_enumerate_impl<'a, F, E>(
-        &'a self,
-        f: F,
-    ) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate_impl<F, E>(&self, f: F) -> Result<Self, CircuitConstructionError>
     where
         Self: Sized,
         CircuitConstructionError: From<E>,
@@ -462,7 +459,7 @@ macro_rules! define_circuit_union_impl {
                 }
             }
 
-            fn map_children_enumerate_impl<'a, F, E>(&'a self, f: F) -> Result<Self, $crate::circuit::CircuitConstructionError>
+            fn map_children_enumerate_impl< F, E>(&self, f: F) -> Result<Self, $crate::circuit::CircuitConstructionError>
             where
                 $crate::circuit::CircuitConstructionError: From<E>,
                 F: FnMut(usize,$crate::circuit::CircuitRc) -> Result<$crate::circuit::CircuitRc, E>,
@@ -714,7 +711,7 @@ impl<T: CircuitNodeUnion> CircuitNode for T {
         self.as_trait_obj().children()
     }
 
-    fn map_children_enumerate<'a, F, E>(&'a self, f: F) -> Result<Self, CircuitConstructionError>
+    fn map_children_enumerate<F, E>(&self, f: F) -> Result<Self, CircuitConstructionError>
     where
         CircuitConstructionError: From<E>,
         F: FnMut(usize, CircuitRc) -> Result<CircuitRc, E>,
