@@ -114,6 +114,18 @@ pub fn repr_circuit_deep_compiler(
                         "".to_owned()
                     }
                 }
+                Circuit::AutoTag(at) => at.uuid.to_string(),
+                Circuit::StoredCumulantVar(scv) => {
+                    format!(
+                        "{}|{}",
+                        scv.cumulants
+                            .keys()
+                            .map(|k| k.to_string())
+                            .collect::<Vec<_>>()
+                            .join(", "),
+                        scv.uuid.to_string(),
+                    )
+                }
                 _ => "".to_owned(),
             }
         });
@@ -296,6 +308,38 @@ pub fn repr_circuit_one_level(
                 repr_op_string(&mn.name_cloned())
             )
         }
+        Circuit::AutoTag(at) => format!(
+            "AutoTag::nrc({}, {}, {})",
+            node_string(&at.node),
+            at.uuid.repr(),
+            repr_op_string(&at.name_cloned())
+        ),
+        Circuit::DiscreteVar(dv) => format!(
+            "DiscreteVar::nrc({},{},{})",
+            node_string(&dv.values),
+            node_string(&dv.probs_and_group),
+            repr_op_string(&dv.name_cloned())
+        ),
+        Circuit::StoredCumulantVar(scv) => format!(
+            "StoredCumulantVar::nrc(BTreeMap::from([{}]),{},{})",
+            scv.cumulants
+                .iter()
+                .map(|(k, v)| format!("({},{})", k.to_string(), node_string(&v)))
+                .collect::<Vec<_>>()
+                .join(","),
+            scv.uuid.repr(),
+            repr_op_string(&scv.name_cloned())
+        ),
+        Circuit::Cumulant(cum) => format!(
+            "Cumulant::nrc(vec![{}],{})",
+            cum.nodes
+                .iter()
+                .map(|v| node_string(&v))
+                .collect::<Vec<_>>()
+                .join(","),
+            repr_op_string(&cum.name_cloned())
+        ),
+        _ => todo!(),
     }
 }
 
