@@ -1,7 +1,7 @@
-use std::{fs::File, io::Write};
-
+use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use itertools::Itertools;
 use smallvec::Array;
+use std::{collections::BTreeMap, fs::File, io::Write};
 use uuid::Uuid;
 
 use super::{
@@ -104,6 +104,33 @@ where
     }
 }
 
+impl<K: RustRepr, V: RustRepr> RustRepr for HashMap<K, V> {
+    fn repr(&self) -> String {
+        let strings: Vec<String> = self
+            .iter()
+            .map(|(k, v)| format!("({},{})", k.repr(), v.repr()))
+            .collect();
+        format!("HashMap::from([{}])", strings.join(","))
+    }
+}
+impl<V: RustRepr> RustRepr for HashSet<V> {
+    fn repr(&self) -> String {
+        format!(
+            "HashSet::from([{}])",
+            self.iter().map(|x| x.repr()).collect::<Vec<_>>().join(",")
+        )
+    }
+}
+impl<K: RustRepr, V: RustRepr> RustRepr for BTreeMap<K, V> {
+    fn repr(&self) -> String {
+        let strings: Vec<String> = self
+            .iter()
+            .map(|(k, v)| format!("({},{})", k.repr(), v.repr()))
+            .collect();
+        format!("BTreeMap::from([{}])", strings.join(","))
+    }
+}
+
 impl RustRepr for RearrangeSpec {
     fn repr(&self) -> String {
         format!(
